@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: adm.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: adm.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -36,28 +36,40 @@ error_reporting(E_ALL);
 
 // ʃvWFNg̐ݒt@C擾邽߂̏
 $is_project_dir = false;
-$define_config  = '';
+$is_app_name    = false;
+$project_dir    = '';
+$app_name       = '';
 foreach ($argv as $arg) {
     if ($is_project_dir) {
-        $define_config = $arg . '/config/defines.xml';
-        break;
+        $project_dir    = $arg;
+        $is_project_dir = false;
+    }
+    if ($is_app_name) {
+        $app_name    = $arg;
+        $is_app_name = false;
     }
     $is_project_dir = ($arg == '-d');
+    $is_app_name    = ($arg == '-w');
 }
 
 if ((array_search('-v', $argv) === false) &&
     (array_search('-h', $argv) === false) &&
     (array_search('--version', $argv) === false) &&
     (array_search('--help',    $argv) === false)) {
-    if (!$define_config) {
-        echo "[SyL error] project directory not found.\nTry `php {$argv[0]} --help' for more information.\n";
+    if (!$project_dir) {
+        echo "[SyL error] Project directory not found.\nTry `php {$argv[0]} --help' for more information.\n";
         exit;
-    } else if (!is_file($define_config)) {
-        echo "[SyL error] invalid config file ({$define_config})\nTry `php {$argv[0]} --help' for more information.\n";
+    }
+    if (!$app_name) {
+        echo "[SyL error] Application name not found.\nTry `php {$argv[0]} --help' for more information.\n";
         exit;
     }
 }
 
+$define_configs = array();
+$define_configs[] = "{$project_dir}/app/{$app_name}/defines.xml";
+$define_configs[] = "{$project_dir}/config/defines.xml";
+
 $syl_dir = dirname(dirname(__FILE__));
 
 require_once $syl_dir . '/SyL.php';
@@ -66,7 +78,7 @@ $config = array(
   'action_key' => 'action',
   'webapp_dir' => $syl_dir . '/opt/adm',
   'app_name'   => 'generate',
-  'define'     => $define_config,
+  'define'     => $define_configs,
   'debug'      => SYL_LOG_DEBUG
 );
 
