@@ -27,22 +27,22 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: setup.php,v 1.5 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: setup.php,v 1.6 2007/07/29 08:54:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 error_reporting(E_ALL);
 
-$SyL_DIR = dirname(dirname(__FILE__));
+$syl_dir = dirname(dirname(__FILE__));
 
-require_once $SyL_DIR . '/SyL.php';
+require_once $syl_dir . '/SyL.php';
 
 $config = array(
   'action_key' => 'action',
-  'webapp_dir' => $SyL_DIR . '/opt/setupcmd',
+  'webapp_dir' => $syl_dir . '/opt/setup',
   'app_name'   => 'setup',
-  'debug'      => SYL_LOG_DEBUG
+  'debug'      => SYL_LOG_INFO
 );
 
 $controller =& SyL_Controller::getController($config);
