@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowUpd.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowUpd extends SyL_AdmFlow
@@ -82,10 +82,11 @@ class SyL_AdmFlowUpd extends SyL_AdmFlow
         $key_name = $form->getStructConfig('key_name');
         // ѥ᡼
         $key = $data->get($key_name);
-        if (!is_string($key)) {
-            // ѥ᡼å
+        if (($key === null) || ($key === '')) {
+            // Բ
             SyL_Response::redirect($this->getUrl('lst'));
         }
+
         // DB³
         $conn =& $this->getDB();
         // ADM֥Ⱥ
