@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,38 +44,11 @@ require_once 'SyL_ContextJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextWeb.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextWeb.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextWeb extends SyL_ContextJs
 {
-    /**
-     * ƥץ졼ȥե
-     * 
-     * @access private
-     * @var string
-     */
-    var $template_file = '';
-
-    /**
-     * ѥ
-     * 
-     * @access private
-     * @param string ѥ
-     * @return string ѥ
-     */
-    function convertPath($path, $is_dir_path=false)
-    {
-        if ($is_dir_path && !preg_match('/(\\\\|\/)$/', $path)) {
-            $path .= '/';
-        } else if (!$is_dir_path) {
-            while (preg_match('/^(\\\\|\/)/', $path)) {
-                $path = substr($path, 1);
-            }
-        }
-        return $path;
-    }
-
     /**
      * ɥե򥻥å
      *
@@ -189,49 +162,6 @@ class SyL_ContextWeb extends SyL_ContextJs
         $this->setViewType('redirect');
         $this->setParameter('_redirect_url', $url);
     }
-
-    /**
-     * ƥץ졼ȥե򥻥å
-     * 
-     * @access public
-     * @param string ƥץ졼ȥե
-     */
-    function setTemplateFile($template_file)
-    {
-        $this->template_file = $template_file;
-    }
-
-    /**
-     * ƥץ졼ȥǥ쥯ȥ
-     * 
-     * @access public
-     * @return string ƥץ졼ȥǥ쥯ȥ
-     */
-    function getTemplateDir()
-    {
-        return $this->convertPath($this->controller->getTemplateDir(), true);
-    }
-
-    /**
-     * ƥץ졼ȥե
-     * 
-     * @access public
-     * @return string ƥץ졼ȥե
-     */
-    function getTemplateFile()
-    {
-        $template_dir  = $this->getTemplateDir();
-        $template_file = $this->convertPath($this->template_file, false);
-
-        // ǥХå - ƥץ졼Ȥξ
-        SyL_Loggers::debug("[Context] template info  dir: {$template_dir} file: {$template_file}");
-
-        // ƥץ졼ȥե¸ߥå
-        if (!is_file($template_dir . $template_file)) {
-            SyL_Response::redirect404();
-        }
-        return $template_file;
-    }
 }
 
 ?>
