@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.12 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.11 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.12 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
@@ -59,11 +59,11 @@ class SyL_ErrorCmd extends SyL_Error
         }
 
         // 顼å
-        $error_message = implode($this->eof, $error_messages) . $this->eof;
+        $error_message = implode($this->eol, $error_messages) . $this->eol;
         // 顼åɽ
         echo $error_message;
         if ($error_trace) {
-            echo $this->eof;
+            echo $this->eol;
             echo $this->getTraceConsole($error_trace);
         }
     }
@@ -80,11 +80,11 @@ class SyL_ErrorCmd extends SyL_Error
         $error_trace_result = '';
         if (count($error_trace) > 0) {
             // 顼ȥ졼ɽκ
-            $error_trace_result .= "------ start Stack Trace ------" . $this->eof;
+            $error_trace_result .= "------ start Stack Trace ------" . $this->eol;
             foreach ($error_trace as $value) {
-                $error_trace_result .= "{$value['no']}. [file] {$value['file']} [line] {$value['line']} [function] {$value['function']}" . $this->eof;
+                $error_trace_result .= "{$value['no']}. [file] {$value['file']} [line] {$value['line']} [function] {$value['function']}" . $this->eol;
             }
-            $error_trace_result .= "------ end Stack Trace ------" . $this->eof;
+            $error_trace_result .= "------ end Stack Trace ------" . $this->eol;
         }
 
         return $error_trace_result;
