@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.4 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.4 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FilterAuth extends SyL_Filter
@@ -78,7 +78,7 @@ class SyL_FilterAuth extends SyL_Filter
     function SyL_FilterAuth()
     {
         // ǧڥ֥Ⱥ
-        $this->auth =& SyL_Auth::getInstance();
+        $this->auth =& SyL_Auth::singleton();
         list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER, 2);
         // ǧڥѥ᡼̾å
         $this->auth->setUserParamaterName($username);
