@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.4 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.5 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.4 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.5 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -218,7 +218,6 @@ class SyL_ActionForm extends SyL_Form
         return $this->maintenance_table;
     }
 
-
     /**
      * ɽΥꥹȤ
      *
@@ -228,9 +227,11 @@ class SyL_ActionForm extends SyL_Form
      */
     function getListColumns($alias='')
     {
+        $i = 1;
         $lists = array();
         // ǰɽ롼
         foreach ($this->elements_config as $name => $values) {
+            $sort = 0;
             // ɽȽ
             if ($alias && isset($values['alias']) && ($values['alias'] != $alias)) {
                 // ̾פʤϼʤ
@@ -242,6 +243,7 @@ class SyL_ActionForm extends SyL_Form
                         // ɽǡɽե饰ɽξϼʤ
                         continue 2;
                     }
+                    $sort = (isset($values['sort_list']) && $values['sort_list']) ? $values['sort_list'] : $i++;
                     break;
                 case 'new':
                 case 'upd':
@@ -250,16 +252,13 @@ class SyL_ActionForm extends SyL_Form
                         // ܺɽǡɽե饰ɽξϼʤ
                         continue 2;
                     }
+                    $sort = (isset($values['sort_detail']) && $values['sort_detail']) ? $values['sort_detail'] : $i++;
                     break;
                 }
             }
-
-            if (isset($values['list']) && $values['list']) {
-                $lists[$values['list']] = $name;
-            } else {
-                $lists[] = $name;
-            }
+            $lists[$sort] = $name;
         }
+        ksort($lists, SORT_NUMERIC);
         return $lists;
     }
 
@@ -272,6 +271,8 @@ class SyL_ActionForm extends SyL_Form
      */
     function build()
     {
+        $i = 1;
+        $elements = array();
         // Ͽ롼
         foreach ($this->elements_config as $name => $values) {
             if (isset($values['display_detail']) && !$values['display_detail']) {
@@ -301,10 +302,20 @@ class SyL_ActionForm extends SyL_Form
                     $element->setValidators($vs);
                 }
             }
-            $this->addElement($element);
+
             $this->elements_config_etc[$name]['cols'] = isset($values['cols']) ? $values['cols'] : '1';
             $this->elements_config_etc[$name]['read_only_new'] = isset($values['read_only_new']) ? $values['read_only_new'] : false;
             $this->elements_config_etc[$name]['read_only_upd'] = isset($values['read_only_upd']) ? $values['read_only_upd'] : false;
+
+            // Ƚ
+            $sort = (isset($values['sort_detail']) && $values['sort_detail']) ? $values['sort_detail'] : $i++;
+            // ¤ӽѹΤ¸
+            $elements[$sort] =& $element;
+        }
+
+        ksort($elements, SORT_NUMERIC);
+        foreach (array_keys($elements) as $name) {
+            $this->addElement($elements[$name]);
         }
     }
 
@@ -442,6 +453,24 @@ class SyL_ActionForm extends SyL_Form
 
         return $results;
     }
+
+
+    /**
+     * ǡ
+     *
+     * @access public
+     * @return array ǡ
+     */
+    function getDataSources()
+    {
+        $result = array();
+        foreach ($this->elements_config as $name => $elements_config) {
+            if (isset($elements_config['data_source']) && $elements_config['data_source']) {
+                $result[$name] = $elements_config['data_source'];
+            }
+        }
+        return $result;
+    }
 }
 
 ?>
