@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.25 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.26 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.25 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.26 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -259,9 +259,9 @@ class SyL_Controller
      * ɤ߹
      *
      * @access public
-     * @param string ɲե
+     * @param array ɲե
      */
-    function readDefines($define='')
+    function readDefines($defines=array())
     {
         $config_files = array();
         // ץꥱͤɤ߹
@@ -272,7 +272,7 @@ class SyL_Controller
         // Хͤɤ߹
         $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
         // ɲե
-        if ($define) {
+        foreach ($defines as $define) {
             $config_files[] = $define;
         }
         $config =& SyL_Config::factory('defines', $config_files, $this);
