@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.12 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.12 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
@@ -93,7 +93,7 @@ class SyL_Logger
      * @access protected
      * @var string
      */
-    var $eof = "\r\n";
+    var $eol = "\r\n";
 
     /**
      * 󥹥ȥ饯
