@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,18 +39,19 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Router.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Router.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Router
 {
     /**
      * ǥեȥե̾
+     * Ƭʸ
      *
      * @access protected
      * @var string
      */
-    var $action_file_default = 'index.php';
+    var $action_file_default = 'Index.php';
     /**
      * URLγĥ
      *
@@ -73,12 +74,12 @@ class SyL_Router
      */
     var $action_file = '';
     /**
-     * ̾
+     * ᥽å̾
      *
      * @access protected
      * @var string
      */
-    var $action_name = '';
+    var $action_method = '';
     /**
      * 饹̾
      *
@@ -118,11 +119,9 @@ class SyL_Router
     /**
      * ܾ󥪥֥ȤΥץѥƥ
      *
-     * $this->action_name
+     * $this->action_method
      * $this->action_file
      * $this->action_class
-     *
-     
      *
      * @access protected
      * @param object ꥯȥ֥
@@ -132,14 +131,14 @@ class SyL_Router
     }
 
     /**
-     * ̾
+     * ᥽å̾
      *
      * @access public
      * @return string ̾
      */
     function getActionName()
     {
-        return $this->action_name;
+        return $this->action_method;
     }
 
     /**
