@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.2 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.3 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.2 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.3 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSqlTableConditions
@@ -150,15 +150,46 @@ class SyL_DBSqlTableConditions
         $this->add($name, $value, $op, $and);
     }
 
+    /**
+     * wheregreater thanӡ
+     *
+     * @access public
+     * @param string ̾
+     * @param string 
+     * @param bool true: =, false: <>
+     * @param bool true: AND, false: OR
+     */
+    function addGt($name, $value, $equal=true, $and=true)
+    {
+        $op = ($equal) ? '>=' : '>';
+        $this->add($name, $value, $op, $and);
+    }
+
+    /**
+     * whereless thanӡ
+     *
+     * @access public
+     * @param string ̾
+     * @param string 
+     * @param bool true: =, false: <>
+     * @param bool true: AND, false: OR
+     */
+    function addLt($name, $value, $equal=true, $and=true)
+    {
+        $op = ($equal) ? '<=' : '<';
+        $this->add($name, $value, $op, $and);
+    }
+
     /**
      * whereNULLӡ
      *
      * @access public
      * @param string ̾
+     * @param string ͡ʥߡ͡
      * @param bool true: IS NULL, false: IS NOT NULL
      * @param bool true: AND, false: OR
      */
-    function addNull($name, $equal=true, $and=true)
+    function addNull($name, $value, $equal=true, $and=true)
     {
         $op = ($equal) ? 'IS NULL' : 'IS NOT NULL';
         $this->add($name, null, $op, $and);
@@ -201,9 +232,10 @@ class SyL_DBSqlTableConditions
      * @access public
      * @param string ̾
      * @param array 
+     * @param bool ʥߡ͡
      * @param bool true: AND, false: OR
      */
-    function addBetween($name, $value, $and=true)
+    function addBetween($name, $value, $equal=true, $and=true)
     {
         if (!is_array($value)) {
             trigger_error("[SyL error] `" . __FUNCTION__ . "' method second parameter Array only", E_USER_ERROR);
@@ -228,6 +260,10 @@ class SyL_DBSqlTableConditions
         case '=':
         case '!=':
         case '<>':
+        case '>':
+        case '>=':
+        case '<':
+        case '<=':
         case 'NULL':
         case 'IS NULL':
         case 'NOT NULL':
